https://github.com/python/cpython/commit/44f1b987ed1908185d8021fd31703b2dd4d97e82
commit: 44f1b987ed1908185d8021fd31703b2dd4d97e82
branch: main
author: Stan Ulbrych <[email protected]>
committer: StanFromIreland <[email protected]>
date: 2026-04-14T07:45:26+01:00
summary:

gh-148487: Fix issues in `test_add_python_opts` (#148507)

files:
M Lib/test/test_regrtest.py

diff --git a/Lib/test/test_regrtest.py b/Lib/test/test_regrtest.py
index 0946289328ccda..02f6e0c74b5ce8 100644
--- a/Lib/test/test_regrtest.py
+++ b/Lib/test/test_regrtest.py
@@ -2230,10 +2230,7 @@ def test_unload_tests(self):
         self.check_executed_tests(output, tests, stats=3)
 
     def check_add_python_opts(self, option):
-        # --fast-ci and --slow-ci add "-u -W default -bb -E" options to Python
-
-        # Skip test if _testinternalcapi is missing
-        import_helper.import_module('_testinternalcapi')
+        # --fast-ci and --slow-ci add "-u -W error -bb -E" options to Python
 
         code = textwrap.dedent(r"""
             import sys
@@ -2248,25 +2245,26 @@ def check_add_python_opts(self, option):
             use_environment = (support.is_emscripten or support.is_wasi)
 
             class WorkerTests(unittest.TestCase):
-                @unittest.skipUnless(config_get is None, 'need config_get()')
+                @unittest.skipIf(config_get is None, 'need config_get()')
                 def test_config(self):
-                    config = config_get()
                     # -u option
                     self.assertEqual(config_get('buffered_stdio'), 0)
-                    # -W default option
-                    self.assertTrue(config_get('warnoptions'), ['default'])
+                    # -W error option
+                    self.assertEqual(config_get('warnoptions'),
+                                     ['error', 'error::BytesWarning'])
                     # -bb option
-                    self.assertTrue(config_get('bytes_warning'), 2)
+                    self.assertEqual(config_get('bytes_warning'), 2)
                     # -E option
-                    self.assertTrue(config_get('use_environment'), 
use_environment)
+                    self.assertEqual(config_get('use_environment'), 
use_environment)
 
                 def test_python_opts(self):
                     # -u option
                     self.assertTrue(sys.__stdout__.write_through)
                     self.assertTrue(sys.__stderr__.write_through)
 
-                    # -W default option
-                    self.assertTrue(sys.warnoptions, ['default'])
+                    # -W error option
+                    self.assertEqual(sys.warnoptions,
+                                     ['error', 'error::BytesWarning'])
 
                     # -bb option
                     self.assertEqual(sys.flags.bytes_warning, 2)

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to